@@ -12,6 +12,7 @@ import argparse
 from typing import (
   Tuple, NamedTuple, Optional, List, Union,
   cast, Dict, Awaitable, Sequence, Any,
+  TYPE_CHECKING,
 )
 import types
 from pathlib import Path
@@ -21,8 +22,16 @@ import contextvars
 import json
 
 import structlog
-import tomli
-import appdirs
+
+if TYPE_CHECKING:
+  import tomli as tomllib
+else:
+  try:
+    import tomllib
+  except ModuleNotFoundError:
+    import tomli as tomllib
+
+import platformdirs
 
 from .lib import nicelogger
 from . import slogconf
@@ -40,7 +49,7 @@ from . import httpclient
 logger = structlog.get_logger(logger_name=__name__)
 
 def get_default_config() -> str:
-  confdir = appdirs.user_config_dir(appname='nvchecker')
+  confdir = platformdirs.user_config_dir(appname='nvchecker')
   file = os.path.join(confdir, 'nvchecker.toml')
   return file
 
@@ -101,11 +110,11 @@ def process_common_arguments(args: argparse.Namespace) -> bool:
     return True
   return False
 
-def safe_overwrite(fname: str, data: Union[bytes, str], *,
+def safe_overwrite(file: Path, data: Union[bytes, str], *,
                    method: str = 'write', mode: str = 'w', encoding: Optional[str] = None) -> None:
   # FIXME: directory has no read perm
-  # FIXME: symlinks and hard links
-  tmpname = fname + '.tmp'
+  # FIXME: hard links
+  tmpname = str(file) + '.tmp'
   # if not using "with", write can fail without exception
   with open(tmpname, mode, encoding=encoding) as f:
     getattr(f, method)(data)
@@ -113,7 +122,7 @@ def safe_overwrite(fname: str, data: Union[bytes, str], *,
     f.flush()
     os.fsync(f.fileno())
   # if the above write failed (because disk is full etc), the old data should be kept
-  os.rename(tmpname, fname)
+  os.rename(tmpname, file.resolve())
 
 def read_verfile(file: Path) -> VersData:
   try:
@@ -140,7 +149,7 @@ def write_verfile(file: Path, versions: VersData) -> None:
     indent=2,
     ensure_ascii=False,
   ) + '\n'
-  safe_overwrite(str(file), data)
+  safe_overwrite(file, data)
 
 class Options(NamedTuple):
   ver_files: Optional[Tuple[Path, Path]]
@@ -157,8 +166,8 @@ def load_file(
 ) -> Tuple[Entries, Options]:
   try:
     with open(file, 'rb') as f:
-      config = tomli.load(f)
-  except (OSError, tomli.TOMLDecodeError) as e:
+      config = tomllib.load(f)
+  except (OSError, tomllib.TOMLDecodeError) as e:
     raise FileLoadError('version configuration file', file, e)
 
   ver_files: Optional[Tuple[Path, Path]] = None
